// FILENAME:	MI_Pluto_1_SandD.cs
//
//------------------------------------------------------------------------------

$missionName = "MI_Pluto_1_SandD";  // DM_Fear_in_Isolation

exec("multiplayerStdLib.cs");
exec("MIConfigCosts.cs");

$MissionCycling::Stage0 = "MercsInc";


function setDefaultMissionOptions()
{
	$server::TeamPlay = true;
	$server::AllowDeathmatch = false;
	$server::AllowTeamPlay = true;	
	
	$server::AllowTeamRed = true;
	$server::AllowTeamBlue = false;
	$server::AllowTeamYellow = false;
	$server::AllowTeamPurple = false;
}


function onMissionStart()
{
	plutoSounds();
}


function onMissionLoad()
{
  $MIstartedMission = 0;
  $MIinGamePlayers = 0;
  if($MItransportPercent == "") $MItransportPercent = 0.05;
  if($MIdifficulty == "") $MIdifficulty = 1;
  if($MIbountyPercent == "") $MIbountyPercent = 0.02;
  if($MIpayUpFront == "") $MIpayUpFront = 0;
  if($MItotalPay == "") $MItotalPay = 1000;
}


//======================


function player::onAdd(%player)
{
  %player.MIloggedIn = 0;
  %player.MIstartMission = 0;
}


function player::onRemove(%player)
{
  Mercs::startCheck();
}


function vehicle::OnAdd(%vehicle)
{
  %player = playermanager::vehicleIDtoPlayerNum(%vehicle);
  if(%player == 0) return;

  if(%player.MIdied == 1)
  {
    damageobject(%vehicle, 50000);
  }


  if($MIstartedMission == 1)
  {
    say(%player, 0, "You cannot join a mission in progress.  Please wait until the mission ends.");
    damageobject(%vehicle, 50000);
  }

  if(%player != 0)
  {
    if(%player.MIloggedIn != 1)
    {
      damageobject(%vehicle, 50000);
      messagebox(%player, "Sorry, this mission has already launched.  Please wait until the battlegroup returns to the lobby.  Thank you for your patience.");
    }
    else
    {
      setTeam(%player, *IDSTR_TEAM_RED);
      redrop(%vehicle);
      %vehicleCost = MIConfigCosts::checkvalue(%vehicle);
      %player.MIvehicleCost = %vehicleCost;
      if(%vehicleCost > (%player.MImoney + 1) )
      {
        messagebox(%player, "Your vehicle cost is $" @ %vehicleCost @ ".  You only have $" @ %player.MImoney @ " in your account.  Please select a less expensive vehicle.");
        damageobject(%vehicle, 50000);
      }
      else
      {
        %player.MItransportCost = round(%vehicleCost * $MItransportPercent);
        messagebox(%player, "Your vehicle cost is $" @ %vehicleCost @ ".  Transport fees will be $" @ %player.MItransportCost @ ".  Please log in again to confirm your selection.");
        Mercs::keepVehicleShutdown(%vehicle);
        %player.MIdied = 0;
      }
    }
  }
}


function vehicle::OnDestroyed(%target, %attacker)
{
  schedule("deleteObject(" @ %target @ ");", 2);

  if($MIstartedMission == 0) return;

  %attackerPlayer = playerManager::vehicleIdToPlayerNum(%attacker);
  %targetPlayer = playerManager::vehicleIdToPlayerNum(%target);

  if(%targetPlayer != 0)
  {
    if(%player.MIloggedIn != 1)
    {
      return;
    }
    else
    {
      say(0, 0, getName(%targetPlayer) @ " is down");
      %player.MIdied = 1;
      say(%targetPlayer, 0, "$ " @ %targetPlayer.MIvehicleCost @ " fee for losing your vehicle.  Please remain in the vicinity until mission end to collect your bonus.");
      %fee = %targetPlayer.MIvehicleCost * -1;
      %targetPlayer.MItransportCost = 0;
      Mercs::addMoney(%targetPlayer, %fee);
      %targetPlayer.MIlostVehicle = 1;
    }
  }

  else
  {
    if(%attackerPlayer == 0) return;

    %points = round(MIConfigCosts::checkValue(%vehicle) * $MIbountyPercent);

    if(%target != %attacker)
    {
      %attackerPlayer.MIbounty = %attackerPlayer.MIbounty + %points;
      say(0, 0, getName(%attackerPlayer) @ " neutralized a Cybrid ($" @ %points @ " bounty).");
    }

    $MItargets--;
    if($MItargets < 1)
    {
      say(0, 0, "Mission complete.");
      Mercs::endMission();
    }
  }

  if($MIinGamePlayers < 1)
  {
    say(0, 0, "Mission failed!");
    $MItotalPay = 0;
    Mercs::endMission();
  }
}



//===================


function Mercs::addMoney(%player, %money)
{
  %player.MImoney = %player.MImoney + %money;
  if(%player.MImoney < 0) %player.MImoney = 0;
  eval("$MIPlayerMoney" @ %player.MIid @ " = " @ %player.MImoney @ ";");  
  Mercs::InscribeRecord();
}


function Mercs::endMission()
{
  Mercs::payouts();

  schedule("missionEndConditionMet();", 10);
}


function Mercs::inscribeRecord()
{
  export("$MIPlayer*", "multiplayer\\MercsIncPlayerList.cs", False);
}


function Mercs::keepVehicleShutdown(%vehicle)
{
  if($MIstartedMission == 1)
  {
    order(%vehicle, shutdown, false);
    return;
  }

  order(%vehicle, shutdown, true);
  schedule("Mercs::keepVehicleShutdown(" @ %vehicle @ ", true);", 1);
}


function Mercs::payouts()
{
  %missionPay = $MItotalPay - $MIpayUpFront;
  %count = playerManager::getPlayerCount();

  %mercCount = 0;

  for(%i = 0; %i < %count; %i++)
  {
    if(%player.MIloggedIn == 1) %mercCount++;
  }

  %missionPayPerPlayer = round(%missionPay / %mercCount);

  for(%i = 0; %i < %count; %i++)
  {
    %player = playerManager::getPlayerNum(%i);
    %player.MIstartMission = 0;

    %playerPayout = 0;
    %playerPayout = %missionPayPerPlayer;
    %playerPayout = %playerPayout + %player.MIbounty;
    %playerPayout = %playerPayout - %player.MItransportCost;
    Mercs::addMoney(%player, %playerPayout);

    if(%playerPayout > 0) %missionNote = "$" @ %missionPay @ " Total pay for " @ %mercCount @ " mercs "; 
     else %missionNote = "";
    if($MIpayUpFront > 0) %upFrontNote = "($" @ $MIpayUpFront @ " up front)";
     else %upFrontNote = "";
    if(%player.MIbounty > 0) %bountyNote = " + $" @ %player.MIbounty @ " kill bounty";
     else %bountyNote = "";
    if(%player.MItransportCost > 0) %transportNote = " - $" @ %player.MItransportCost @ " transport fees";
     else %transportNote = "";
    if(%player.MIlostVehicle == 1) %lostVehNote = " - $" @ %player.MIvehicleCost @ " (lost vehicle)";
     else %lostVehNote = "";

    messagebox(%player, "Your payout: " @ %missionNote @ %upFrontNote @ %bountyNote @ %transportNote @ %lostVehNote @ " = Total payout $" @ %playerPayout @ 
         ". \n Your new account: $" @ %player.MImoney);
  }
}


function Mercs::startCheck()
{
  %ready = 1;
  %waitingFor = 0;

  %count = playerManager::getPlayerCount();

  if(%count == 0)
  {
    Mercs::endMission();
  }

  for(%i = 0; %i < %count; %i++)
  {
    %player = playerManager::getPlayerNum(%i);
    if(%player.MIstartMission != 1)
    {
      %ready = 0;
      %waitingFor++;
    }
  }

  if(%ready == 0)
  {
    say(0, 0, "Waiting for " @ %waitingFor @ " players.");
  }

  else
  {
    say(0, 0, "All pilots have logged in.  Initiating mission.");
    Mercs::startMission();
  }
}


function Mercs::startMission()                 // Testing
{
  $MIstartedMission = 1;

  %player = playerManager::getPlayerNum(0);
  %vehicle = playerManager::playerNumToVehicleId(%player);
  %x = getPosition(%vehicle, x);
  %y = getPosition(%vehicle, y);

  $MItargets = randomInt(1, 3);

  for(%i=0; %i<$MItargets; %i++)
  {
    %herc = NewObject("Goadie", Herc, 21 ); 
    setTeam( %herc, *IDSTR_TEAM_PURPLE );
    setPilotId(%herc,28);

    %distance = 0;
    while(%distance < 100 || %distance > 300)
    {
      %x2 = randomInt(1000, 2000);
      %y2 = randomInt(-1700, -700);

      %xsqr = (%x - %x2) * (%x - %x2);
      %ysqr = (%y - %y2) * (%y - %y2);

      %distance = sqrt( %xsqr + %ysqr);
    }

    %z2 = getTerrainHeight(%x2, %y2);
    setPosition(%herc, %x2, %y2, %z2);

    order( %herc, shutdown, true );
  }
}

//===================


function remoteMercs::Login(%player, %password)
{
  if(%player.MIstartMission == 1) return;

  if(%player.MIloggedIn != 1)
  {
    messagebox(%player, "Sorry, this mission has already launched.  Please wait until the battlegroup returns to the lobby.  Thank you for your patience.");
  }
  else
  {
    $MIInGamePlayers++;
    %player.MIstartMission = 1;
    %player.MIbounty = 0;
    %player.MIlostVehicle = 0;
    say(0, 0, getName(%player) @ " has logged in.");
    Mercs::startCheck();
  }
}


//===================



function round(%number)
{
   %roundNum = %number;
   if(%number > 0)
   {
      %excess = (%number - floor(%number));
      if(%excess >= 0.5)
      {
         %roundNum = (floor(%number) + 1);
      }
      else
      {
         %roundNum = floor(%number);
      }
   }
   if(%number < 0)
   {
      %excess = (floor(%number) - %number);
      if(%excess <= 0.5)
      {
         %roundNum = floor(%number);
      }
      else
      {
         %roundNum = (floor(%number) - 1);
      }
   }
   return %roundNum;
}


Pilot Goadie
{
   id = 28;
   
   skill = 0.2;
   accuracy = 0.2;
   aggressiveness = 0.5;
   activateDist = 2000.0;
   deactivateBuff = 3000.0;
   targetFreq = 4.0;
   trackFreq = 0.1;
   fireFreq = 0.1;
   LOSFreq = 0.4;
   name = "Hapless";
};
